Leo's Home Page

### Navigation

- index
- glossary |
- contents |
- Leo 6.0 documentation

# Leo’s Home Page

> "Leo is a revolutionary step in the right direction for programming."―Brian Takita

> "Leo is the best IDE that I have had the pleasure to use. It has totally changed not only the way that I program, but also the way that I store and organize all of the information that I need for the job that I do."―Ian Mulvany

> "When first I opened Leo, it was out of curiosity. But having used it, I'll never go back. They'll have to pry Leo out of my cold, dead fingers!"―Travers A. Hough

Leo is a PIM, IDE and outliner that accelerates the work flow of programmers, authors and web designers. Outline nodes may appear in more than one place, allowing multiple organizations of data within a single outline.

Joe Orr's must see demo.
A brief summary of Leo.
What people are saying about Leo.
Learn about Leo in 20 minutes.

Ask us anything at the leo-editor Google Group.
Send us a postcard, telling how you use Leo. Thanks!

Here is reduced screenshot of Leo's main window. You can view the full-sized image using something like "view image" in your browser.

### Navigation

- index
- glossary |
- contents |
- Leo 6.0 documentation